# Copyright 1999-2005 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

inherit eutils depend.apache multilib autotools

DESCRIPTION="A feature-rich open source mailing list software"
HOMEPAGE="http://www.sympa.org/features.html"
SRC_URI="http://www.sympa.org/distribution/${P}.tar.gz"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="~x86 ~amd64"
IUSE="mysql postgres sqlite sqlite3 ldap fastcgi apache2 ssl soap nfs"

DEPEND="
	sys-devel/gettext
	dev-lang/perl
	"
# See http://www.sympa.org/wiki/manual/installing-sympa#required_cpan_modules
RDEPEND="
	${DEPEND_APACHE}
	virtual/perl-CGI
	virtual/perl-DB_File
	virtual/perl-Digest-MD5
	virtual/perl-File-Spec
	virtual/perl-MIME-Base64
	virtual/perl-libnet
	dev-perl/Archive-Zip
	dev-perl/Crypt-CipherSaber
	dev-perl/DBI
	dev-perl/IO-stringy
	dev-perl/MIME-Charset
	dev-perl/MIME-EncWords
	dev-perl/MIME-tools
	dev-perl/MailTools
	dev-perl/Template-Toolkit
	dev-perl/XML-LibXML
	dev-perl/libintl-perl
	dev-perl/libwww-perl
	dev-perl/regexp-common
	fastcgi? ( dev-perl/FCGI )
	ldap? ( dev-perl/perl-ldap )
	mysql? ( dev-perl/DBD-mysql )
	net-mail/mhonarc
	nfs? ( dev-perl/File-NFSLock )
	postgres? ( dev-perl/DBD-Pg )
	soap? ( dev-perl/SOAP-Lite )
	sqlite? ( dev-perl/DBD-SQLite2 )
	sqlite3? ( dev-perl/DBD-SQLite )
	ssl? ( dev-perl/IO-Socket-SSL dev-perl/Net-SSLeay )
	virtual/mta
	"
# TODO
# perl suid
# apache2? conf
# DBD-Oracle
# DBD-Sybase
# clamav? ( app-antivirus/clamav )
# >=sys-libs/db-4.1 ?
# include version in R?DEPEND

# BUG
# DEPEND_APACHE is wrong, any CGI-enabled web server is fine
# config files are need to be modified

MY_SYMPAUSER="sympa"
MY_SYMPAGROUP="sympa"
MY_VER=${PV/%.?/}
pkg_setup() {
	if ! useq mysql && ! useq postgres && ! useq sqlite && ! useq sqlite3; then
		eerror
		eerror "You have not specified any supported database backend in your USE flags"
		eerror "Supported database backends:"
		eerror "mysql, postgres, sqlite & sqlite3"
		eerror
		die "No database backend specified"
	fi
	enewgroup ${MY_SYMPAGROUP}
	enewuser ${MY_SYMPAUSER} -1 -1 -1 ${MY_SYMPAGROUP}
}

src_unpack() {
	unpack ${A}
	cd ${S}
	# Add suid wrappers
	epatch ${FILESDIR}/${PN}-${MY_VER}.sympa-wrappers.patch
	# Ignore interactive scripts / Enable custom CFLAGS
	epatch ${FILESDIR}/${PN}-${MY_VER}.Makefile.patch
	# Disable broken SQLite upgrade procedure
	epatch ${FILESDIR}/${PN}-${MY_VER}.disable_sqlite_upgrade.patch
	# Install SUID wrappers
	cp ${FILESDIR}/wwsympa-wrapper.fcgi.c ${S}/wwsympa
	cp ${FILESDIR}/sympa_soap_server-wrapper.fcgi.c ${S}/soap
	# Gentoo specific
	epatch ${FILESDIR}/${PN}-${MY_VER}.gentoo_default_config.patch
	epatch ${FILESDIR}/${PN}-${MY_VER}.gentoo_ignore_keep.patch
	# Fix for SQLite
	epatch ${FILESDIR}/${PN}-${MY_VER}.sqlite_fix.patch
	eautoreconf
}
src_compile() {
	# BUG:
	# --without-foodir doesn't work, thus neither "doc" nor "nls" work
	# --with-piddir=/var/run ?
	# FIXED:
	# use multilib
	econf \
		--prefix=/usr \
		--with-sbindir=/usr/sbin \
		--with-spooldir=/var/spool/sympa \
		--with-confdir=/etc/sympa \
		--with-etcdir=/etc/sympa \
		--with-cgidir=/usr/libexec/sympa \
		--with-iconsdir=/usr/share/sympa/icons \
		--with-datadir=/usr/share/sympa \
		--with-expldir=/var/lib/sympa/lists \
		--with-libdir=/usr/$(get_libdir)/sympa \
		--with-scriptdir=/usr/share/sympa/scripts \
		--with-initdir=/usr/share/sympa/scripts \
		--with-sampledir=/usr/share/doc/${P}/example \
		--with-piddir=/var/run/sympa \
		--with-mandir=/usr/share/man \
		--with-docdir=/usr/share/doc/${P} \
		--with-localedir=/usr/share/locale \
		|| die "econf failed"
	emake CFLAGS="${CFLAGS} -Wl,-z,now" || die "emake failed."
}

src_install() {

	make DESTDIR="${D}" install || die "make install failed"
	dodoc AUTHORS COPYING ChangeLog INSTALL NEWS README

	#rm ${D}/usr/share/sympa/{README,ca-bundle.crt}
	#rm -R ${D}/usr/share/sympa/create_list_templates/{html-news-letter,hotline,intranet_list,public_web_forum}

	# BUG:
	# broken
	newinitd ${FILESDIR}/${PN}-${MY_VER}.initd ${PN}
	#cp ${FILESDIR}/sympa.init ${D}/etc/init.d/sympa
	# use *-dist
	#cp ${FILESDIR}/*.conf ${D}/etc/sympa
	# BUG use keepdir

	# FIXED:
	# patching files accordingly
	#
	# sympa writes pid files *AFTER* dropping priv
	keepdir /var/run/sympa
	fowners ${MY_SYMPAUSER}:${MY_SYMPAGROUP} /var/run/sympa
	# Set proper fastcgi flag
	if ! use fastcgi ; then
		sed -i 's/^\(use_fast_cgi[[:blank:]]*\).*/\10/' ${D}/etc/sympa/wwsympa.conf
	fi
	# Set permissions on config files
	fperms 0640 /etc/sympa/sympa.conf /etc/sympa/wwsympa.conf
	# queue dirs
	keepdir /var/spool/sympa
	local MY_DIRS="arc auth automatic bounce digest distribute expire \
		moderation msg outgoing qbounce static_content subscribe task tmp topic"
	local MY_DIR
	for MY_DIR in ${MY_DIRS}; do
		keepdir /var/spool/sympa/${MY_DIR}
		fowners ${MY_SYMPAUSER}:${MY_SYMPAGROUP} /var/spool/sympa/${MY_DIR}
		case "${MY_DIR}" in
			"static_content" )
				fperms 755 /var/spool/sympa/${MY_DIR}
			;;
			* )
				fperms 750 /var/spool/sympa/${MY_DIR}
			;;
		esac
	done
	keepdir /var/lib/sympa
	keepdir /var/lib/sympa/lists
	fowners ${MY_SYMPAUSER}:${MY_SYMPAGROUP} /var/lib/sympa/lists

	#--------------------------------------------------
	# # BUG:
	# # APACHE2?_MODULES_CONFDIR is for apache modules
	newdoc ${FILESDIR}/${PN}-${MY_VER}.apache.conf apache.conf || \
		die "newdoc failed"
	newdoc ${FILESDIR}/${PN}-${MY_VER}.apache_soap.conf apache_soap.conf || \
		die "newdoc failed"
	newdoc ${FILESDIR}/${PN}-${MY_VER}.lighttpd.conf lighttpd.conf ||\
		die "newdoc failed"
	newdoc ${FILESDIR}/${PN}-${MY_VER}.lighttpd_soap.conf lighttpd_soap.conf ||\
		die "newdoc failed"
	#
	# if use apache2; then
	# 	if use soap ; then
	# 		insinto ${APACHE2_MODULES_CONFDIR}
	# 		newins ${FILESDIR}/${P}.apache_soap.conf sympa_soap.conf
	# 	fi
	# 	insinto ${APACHE2_MODULES_CONFDIR}
	# 	newins ${FILESDIR}/${P}.apache.conf sympa.conf
	# else
	# 	if use soap ; then
	# 		insinto ${APACHE1_MODULES_CONFDIR}
	# 		newins ${FILESDIR}/${P}.apache_soap.conf sympa_soap.conf
	# 	fi
	# 	insinto ${APACHE1_MODULES_CONFDIR}
	# 	newins ${FILESDIR}/${P}.apache.conf sympa.conf
	# fi
	#-------------------------------------------------- 
	#--------------------------------------------------
	# BUG:
	# should be fixed in the upstream, if it's really a problem
	# patching Makefile.am is preferred
	#
	# # This application's installer automatically sets the ownership and
	# # permissions of a large number of its files; its choices are borderlining
	# # on warranting a patch to completely disable that behavior.
	# chown -R root:root ${D}/usr/share
	# chown root:root ${D}/etc/sympa ${D}/etc/sympa/wwsympa.conf
	# chown root:sympa ${D}/etc/sympa/sympa.conf ${D}/usr/share/doc/sympa/examples/sympa.conf
	# chown -R root:root ${D}/usr/lib/sympa
	# chown -R root:root ${D}/usr/sbin
	# chown -R sympa:sympa ${D}/var/sympa
	# find ${D}/usr/share/sympa -type f -exec chmod 644 {} \;
	# chmod 640 ${D}/etc/sympa/sympa.conf ${D}/usr/share/doc/sympa/examples/sympa.conf
	# chmod 644 ${D}/etc/sympa/wwsympa.conf ${D}/usr/share/doc/sympa/examples/wwsympa.conf
	# chmod 644 ${D}/usr/share/man/man8/*
	# chmod 750 ${D}/var/sympa/lists
	#--------------------------------------------------
}

pkg_postinst() {
	einfo
	einfo "You need to create a database and database user account for sympa prior to"
	einfo "starting the application; that account will need general access privileges"
	einfo "to the sympa database."
	einfo
	einfo "The Sympa web interface needs to be setup in Apache. Please consult the"
	einfo "Sympa documentation found at <http://www.sympa.org> for more information."
	einfo "Sample configs are installed in /usr/share/doc/${P}."
	einfo
}
